# eric7.EricNetwork.EricJsonStreamWriter

Module implementing a JSON based writer class.

### Global Attributes

None

### Classes

EricJsonWriter | Class implementing a JSON based writer class.

### Functions

None

## EricJsonWriter

Class implementing a JSON based writer class.

### Derived from

None

### Class Attributes

None

### Class Methods

None

### Methods

EricJsonWriter | Constructor
close | Public method to close the stream.
write | Public method to send JSON serializable data.

### Static Methods

None

#### EricJsonWriter (Constructor)

EricJsonWriter(host, port)

Constructor

host (str)
  IP address the reader is listening on
port (int)
  port the reader is listening on

#### EricJsonWriter.close

close()

Public method to close the stream.

#### EricJsonWriter.write

write(data)

Public method to send JSON serializable data.

data (object)
  JSON serializable object to be sent

Up